sipzamine
=========

Command line SIP dialog matching and searching through offline PCAPs

TODO
----

- Upload to PyPI.
- Add help text from https://code.osso.nl/projects/sipp.
- Add tests: begin with a smallish pcap.
- Add the ability to write pcaps from the filter. Combine capability
  with sipscrub?
- Compare this to sipgrep (and other tools?). And homer?

See also:
---------

- https://github.com/ossobv/vcutil/blob/master/tcpdump247
